==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/EnvFromSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface EnvFromSourceFluent<A extends io.fabric8.kubernetes.api.model.EnvFromSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildConfigMapRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ConfigMapEnvSource getConfigMapRef();
  public io.fabric8.kubernetes.api.model.ConfigMapEnvSource buildConfigMapRef();
  public A withConfigMapRef(io.fabric8.kubernetes.api.model.ConfigMapEnvSource configMapRef);
  public java.lang.Boolean hasConfigMapRef();
  public A withNewConfigMapRef(java.lang.String name,java.lang.Boolean optional);
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.ConfigMapRefNested<A> withNewConfigMapRef();
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.ConfigMapRefNested<A> withNewConfigMapRefLike(io.fabric8.kubernetes.api.model.ConfigMapEnvSource item);
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.ConfigMapRefNested<A> editConfigMapRef();
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.ConfigMapRefNested<A> editOrNewConfigMapRef();
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.ConfigMapRefNested<A> editOrNewConfigMapRefLike(io.fabric8.kubernetes.api.model.ConfigMapEnvSource item);
  public java.lang.String getPrefix();
  public A withPrefix(java.lang.String prefix);
  public java.lang.Boolean hasPrefix();
  
  /**
   * Method is deprecated. use withPrefix instead.
   */
  @java.lang.Deprecated
  public A withNewPrefix(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretEnvSource getSecretRef();
  public io.fabric8.kubernetes.api.model.SecretEnvSource buildSecretRef();
  public A withSecretRef(io.fabric8.kubernetes.api.model.SecretEnvSource secretRef);
  public java.lang.Boolean hasSecretRef();
  public A withNewSecretRef(java.lang.String name,java.lang.Boolean optional);
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.SecretRefNested<A> withNewSecretRef();
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.SecretRefNested<A> withNewSecretRefLike(io.fabric8.kubernetes.api.model.SecretEnvSource item);
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.SecretRefNested<A> editSecretRef();
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.SecretRefNested<A> editOrNewSecretRef();
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(io.fabric8.kubernetes.api.model.SecretEnvSource item);
  public interface ConfigMapRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ConfigMapEnvSourceFluent<io.fabric8.kubernetes.api.model.EnvFromSourceFluent.ConfigMapRefNested<N>>{
    public N and();
    public N endConfigMapRef();
    
  }
  public interface SecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SecretEnvSourceFluent<io.fabric8.kubernetes.api.model.EnvFromSourceFluent.SecretRefNested<N>>{
    public N and();
    public N endSecretRef();
    
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/EnvFromSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface EnvFromSourceFluent<A extends io.fabric8.kubernetes.api.model.EnvFromSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildConfigMapRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ConfigMapEnvSource getConfigMapRef();
  public io.fabric8.kubernetes.api.model.ConfigMapEnvSource buildConfigMapRef();
  public A withConfigMapRef(io.fabric8.kubernetes.api.model.ConfigMapEnvSource configMapRef);
  public java.lang.Boolean hasConfigMapRef();
  public A withNewConfigMapRef(java.lang.String name,java.lang.Boolean optional);
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.ConfigMapRefNested<A> withNewConfigMapRef();
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.ConfigMapRefNested<A> withNewConfigMapRefLike(io.fabric8.kubernetes.api.model.ConfigMapEnvSource item);
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.ConfigMapRefNested<A> editConfigMapRef();
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.ConfigMapRefNested<A> editOrNewConfigMapRef();
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.ConfigMapRefNested<A> editOrNewConfigMapRefLike(io.fabric8.kubernetes.api.model.ConfigMapEnvSource item);
  public java.lang.String getPrefix();
  public A withPrefix(java.lang.String prefix);
  public java.lang.Boolean hasPrefix();
  
  /**
   * Method is deprecated. use withPrefix instead.
   */
  @java.lang.Deprecated
  public A withNewPrefix(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SecretEnvSource getSecretRef();
  public io.fabric8.kubernetes.api.model.SecretEnvSource buildSecretRef();
  public A withSecretRef(io.fabric8.kubernetes.api.model.SecretEnvSource secretRef);
  public java.lang.Boolean hasSecretRef();
  public A withNewSecretRef(java.lang.String name,java.lang.Boolean optional);
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.SecretRefNested<A> withNewSecretRef();
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.SecretRefNested<A> withNewSecretRefLike(io.fabric8.kubernetes.api.model.SecretEnvSource item);
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.SecretRefNested<A> editSecretRef();
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.SecretRefNested<A> editOrNewSecretRef();
  public io.fabric8.kubernetes.api.model.EnvFromSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(io.fabric8.kubernetes.api.model.SecretEnvSource item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ConfigMapRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ConfigMapEnvSourceFluent<io.fabric8.kubernetes.api.model.EnvFromSourceFluent.ConfigMapRefNested<N>>{
    public N and();
    public N endConfigMapRef();
    
  }
  public interface SecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SecretEnvSourceFluent<io.fabric8.kubernetes.api.model.EnvFromSourceFluent.SecretRefNested<N>>{
    public N and();
    public N endSecretRef();
    
  }
  
}
